# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.sketch_metric import SketchMetric

class TestSketchMetric(unittest.TestCase):
    """SketchMetric unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SketchMetric:
        """Test SketchMetric
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SketchMetric`
        """
        model = SketchMetric()
        if include_optional:
            return SketchMetric(
                name = '',
                sketch_series = [
                    arthur_client.api_bindings.models.sketch_time_series.SketchTimeSeries(
                        dimensions = [
                            arthur_client.api_bindings.models.dimension.Dimension(
                                name = '', 
                                value = '', )
                            ], 
                        values = [
                            arthur_client.api_bindings.models.sketch_point.SketchPoint(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = '', )
                            ], )
                    ]
            )
        else:
            return SketchMetric(
                name = '',
                sketch_series = [
                    arthur_client.api_bindings.models.sketch_time_series.SketchTimeSeries(
                        dimensions = [
                            arthur_client.api_bindings.models.dimension.Dimension(
                                name = '', 
                                value = '', )
                            ], 
                        values = [
                            arthur_client.api_bindings.models.sketch_point.SketchPoint(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = '', )
                            ], )
                    ],
        )
        """

    def testSketchMetric(self):
        """Test SketchMetric"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
